@@ -1370,6 +1370,7 @@ func (a *App) apply(r *Run, c ApplyConfigProvider) (bool, bool, []error) {
 		ResetValues:       c.ResetValues(),
 		DiffArgs:          c.DiffArgs(),
 		PostRenderer:      c.PostRenderer(),
+		PostRendererArgs:  c.PostRendererArgs(),
 	}
 
 	infoMsg, releasesToBeUpdated, releasesToBeDeleted, errs := r.diff(false, detailedExitCode, c, diffOpts)
@@ -1472,14 +1473,15 @@ Do you really want to apply?
 				subst.Releases = rs
 
 				syncOpts := &state.SyncOpts{
-					Set:          c.Set(),
-					SkipCleanup:  c.RetainValuesFiles() || c.SkipCleanup(),
-					SkipCRDs:     c.SkipCRDs(),
-					Wait:         c.Wait(),
-					WaitForJobs:  c.WaitForJobs(),
-					ReuseValues:  c.ReuseValues(),
-					ResetValues:  c.ResetValues(),
-					PostRenderer: c.PostRenderer(),
+					Set:              c.Set(),
+					SkipCleanup:      c.RetainValuesFiles() || c.SkipCleanup(),
+					SkipCRDs:         c.SkipCRDs(),
+					Wait:             c.Wait(),
+					WaitForJobs:      c.WaitForJobs(),
+					ReuseValues:      c.ReuseValues(),
+					ResetValues:      c.ResetValues(),
+					PostRenderer:     c.PostRenderer(),
+					PostRendererArgs: c.PostRendererArgs(),
 				}
 				return subst.SyncReleases(&affectedReleases, helm, c.Values(), c.Concurrency(), syncOpts)
 			}))
@@ -1591,6 +1593,8 @@ func (a *App) diff(r *Run, c DiffConfigProvider) (*string, bool, bool, []error)
 
 		var errs []error
 
+		helm.SetExtraArgs(GetArgs(c.Args(), r.state)...)
+
 		opts := &state.DiffOpts{
 			Context:           c.Context(),
 			Output:            c.DiffOutput(),
@@ -1602,6 +1606,7 @@ func (a *App) diff(r *Run, c DiffConfigProvider) (*string, bool, bool, []error)
 			ReuseValues:       c.ReuseValues(),
 			ResetValues:       c.ResetValues(),
 			PostRenderer:      c.PostRenderer(),
+			PostRendererArgs:  c.PostRendererArgs(),
 		}
 
 		filtered := &Run{
@@ -1861,13 +1866,14 @@ Do you really want to sync?
 				subst.Releases = rs
 
 				opts := &state.SyncOpts{
-					Set:          c.Set(),
-					SkipCRDs:     c.SkipCRDs(),
-					Wait:         c.Wait(),
-					WaitForJobs:  c.WaitForJobs(),
-					ReuseValues:  c.ReuseValues(),
-					ResetValues:  c.ResetValues(),
-					PostRenderer: c.PostRenderer(),
+					Set:              c.Set(),
+					SkipCRDs:         c.SkipCRDs(),
+					Wait:             c.Wait(),
+					WaitForJobs:      c.WaitForJobs(),
+					ReuseValues:      c.ReuseValues(),
+					ResetValues:      c.ResetValues(),
+					PostRenderer:     c.PostRenderer(),
+					PostRendererArgs: c.PostRendererArgs(),
 				}
 				return subst.SyncReleases(&affectedReleases, helm, c.Values(), c.Concurrency(), opts)
 			}))
@@ -1901,6 +1907,7 @@ func (a *App) template(r *Run, c TemplateConfigProvider) (bool, []error) {
 			SkipCleanup:       c.SkipCleanup(),
 			SkipTests:         c.SkipTests(),
 			PostRenderer:      c.PostRenderer(),
+			PostRendererArgs:  c.PostRendererArgs(),
 			KubeVersion:       c.KubeVersion(),
 		}
 		return st.TemplateReleases(helm, c.OutputDir(), c.Values(), args, c.Concurrency(), c.Validate(), opts)
